@@ -333,6 +333,7 @@ class VerifyCommands(object):
             if extra_options:
                 if os.path.isfile(extra_options):
                     conf = configparser.ConfigParser()
+                    conf.optionxform = str
                     conf.read(extra_options)
                     extra_options = dict(conf._sections)
                     for s in extra_options:
@@ -525,6 +526,13 @@ class VerifyCommands(object):
         else:
             print("Verification UUID: %s." % verification_uuid)
 
+        if results["totals"]["unexpected_success"] > 0:
+            return 2
+        if results["totals"]["failures"] > 0:
+            return 3
+
+        return 0
+
     @cliutils.help_group("verification")
     @cliutils.args("--uuid", dest="verification_uuid", type=str, required=True,
                    help="Verification UUID. " + LIST_VERIFICATIONS_HINT)
