@@ -19,8 +19,6 @@ import hashlib
 import itertools
 import json
 
-import six
-
 from rally.common import objects
 from rally.common.plugin import plugin
 from rally.common import version
@@ -243,7 +241,7 @@ def plot(tasks_results, include_libs=False):
                            include_libs=include_libs)
 
 
-def trends(tasks):
+def trends(tasks, include_libs=False):
     trends = Trends()
     for task in tasks:
         for workload in itertools.chain(
@@ -251,7 +249,8 @@ def trends(tasks):
             trends.add_result(task["uuid"], workload)
     template = ui_utils.get_template("task/trends.html")
     return template.render(version=version.version_string(),
-                           data=json.dumps(trends.get_data()))
+                           data=json.dumps(trends.get_data()),
+                           include_libs=include_libs)
 
 
 class Trends(object):
@@ -269,7 +268,7 @@ class Trends(object):
         """Convert object into string."""
         if obj is None:
             return "None"
-        elif isinstance(obj, six.string_types + (int, float)):
+        elif isinstance(obj, (str, int, float)):
             return str(obj).strip()
         elif isinstance(obj, (list, tuple)):
             return ",".join(sorted([self._to_str(v) for v in obj]))
@@ -304,8 +303,8 @@ class Trends(object):
                 "config": workload_cfg}
 
         self._data[key]["tasks"].append(task_uuid)
-        if (self._data[key]["description"] and
-                self._data[key]["description"] != w_description):
+        if (self._data[key]["description"]
+                and self._data[key]["description"] != w_description):
             self._data[key]["description"] = None
 
         self._data[key]["sla_failures"] += not workload["pass_sla"]
@@ -387,7 +386,7 @@ class Trends(object):
                                ("avg", charts.streaming.MeanComputation())):
                 for k, v in trend["durations"]:
                     for i in v:
-                        if isinstance(i[1], (float,) + six.integer_types):
+                        if isinstance(i[1], (float, int)):
                             comp.add(i[1])
                 trend["stat"][stat] = comp.result()
 
