@@ -14,10 +14,9 @@
 #    under the License.
 
 import collections
+import io
 import os
-
-import mock
-import six
+from unittest import mock
 
 from rally.cli import cliutils
 from rally.cli.commands import deployment
@@ -52,81 +51,45 @@ class DeploymentCommandsTestCase(test.TestCase):
         self.fake_api.deployment.create.assert_called_once_with(
             config={}, name="fake_deploy")
 
-    @mock.patch.dict(os.environ, {"OS_AUTH_URL": "fake_auth_url",
-                                  "OS_USERNAME": "fake_username",
-                                  "OS_PASSWORD": "fake_password",
-                                  "OS_TENANT_NAME": "fake_tenant_name",
-                                  "OS_REGION_NAME": "fake_region_name",
-                                  "OS_ENDPOINT_TYPE": "fake_endpoint_typeURL",
-                                  "OS_ENDPOINT": "fake_endpoint",
-                                  "OS_INSECURE": "True",
-                                  "OS_CACERT": "fake_cacert",
-                                  "RALLY_DEPLOYMENT": "fake_deployment_id",
-                                  "OSPROFILER_HMAC_KEY": "fake_hmac_key",
-                                  "OSPROFILER_CONN_STR": "fake_conn_str"})
-    @mock.patch("rally.cli.commands.deployment.DeploymentCommands.list")
-    def test_createfromenv_keystonev2(self, mock_list):
+    @mock.patch("rally.env.env_mgr.EnvManager.create_spec_from_sys_environ",
+                return_value={"spec": {"auth_url": "http://fake"}})
+    def test_create_fromenv(self, mock_create_spec_from_sys_environ):
         self.deployment.create(self.fake_api, "from_env", True)
         self.fake_api.deployment.create.assert_called_once_with(
-            config={
-                "openstack": {
-                    "auth_url": "fake_auth_url",
-                    "region_name": "fake_region_name",
-                    "endpoint_type": "fake_endpoint_type",
-                    "endpoint": "fake_endpoint",
-                    "admin": {
-                        "username": "fake_username",
-                        "password": "fake_password",
-                        "tenant_name": "fake_tenant_name"
-                    },
-                    "https_insecure": True,
-                    "https_cacert": "fake_cacert",
-                    "profiler_hmac_key": "fake_hmac_key",
-                    "profiler_conn_str": "fake_conn_str"
-                }
-            },
+            config={"auth_url": "http://fake"},
             name="from_env"
         )
 
-    @mock.patch.dict(os.environ, {"OS_AUTH_URL": "fake_auth_url",
-                                  "OS_USERNAME": "fake_username",
-                                  "OS_PASSWORD": "fake_password",
-                                  "OS_TENANT_NAME": "fake_tenant_name",
-                                  "OS_REGION_NAME": "fake_region_name",
-                                  "OS_ENDPOINT_TYPE": "fake_endpoint_typeURL",
-                                  "OS_PROJECT_DOMAIN_NAME": "fake_pdn",
-                                  "OS_USER_DOMAIN_NAME": "fake_udn",
-                                  "OS_ENDPOINT": "fake_endpoint",
-                                  "OS_INSECURE": "True",
-                                  "OS_CACERT": "fake_cacert",
-                                  "RALLY_DEPLOYMENT": "fake_deployment_id",
-                                  "OSPROFILER_HMAC_KEY": "fake_hmac_key",
-                                  "OSPROFILER_CONN_STR": "fake_conn_str"})
-    @mock.patch("rally.cli.commands.deployment.DeploymentCommands.list")
-    def test_createfromenv_keystonev3(self, mock_list):
-        self.deployment.create(self.fake_api, "from_env", True)
-        self.fake_api.deployment.create.assert_called_once_with(
-            config={
-                "openstack": {
-                    "auth_url": "fake_auth_url",
-                    "region_name": "fake_region_name",
-                    "endpoint_type": "fake_endpoint_type",
-                    "endpoint": "fake_endpoint",
-                    "admin": {
-                        "username": "fake_username",
-                        "password": "fake_password",
-                        "user_domain_name": "fake_udn",
-                        "project_domain_name": "fake_pdn",
-                        "project_name": "fake_tenant_name"
-                    },
-                    "https_insecure": True,
-                    "https_cacert": "fake_cacert",
-                    "profiler_hmac_key": "fake_hmac_key",
-                    "profiler_conn_str": "fake_conn_str"
+    @mock.patch("rally.env.env_mgr.EnvManager.create_spec_from_sys_environ")
+    def test_create_fromenv_openstack(self, mock_create_spec_from_sys_environ):
+
+        mock_create_spec_from_sys_environ.side_effect = lambda: {
+            "spec": {
+                "existing@openstack": {
+                    "https_key": "some key",
+                    "another_key": "another"
                 }
-            },
-            name="from_env"
-        )
+            }
+        }
+        mock_rally_os = mock.Mock()
+        mock_rally_os.__version_tuple__ = (1, 4, 0)
+
+        with mock.patch.dict("sys.modules",
+                             {"rally_openstack": mock_rally_os}):
+            self.deployment.create(self.fake_api, "from_env", True)
+            self.fake_api.deployment.create.assert_called_once_with(
+                config={"existing@openstack": {"another_key": "another"}},
+                name="from_env"
+            )
+
+            self.fake_api.deployment.create.reset_mock()
+            mock_rally_os.__version_tuple__ = (1, 5, 0)
+            self.deployment.create(self.fake_api, "from_env", True)
+            self.fake_api.deployment.create.assert_called_once_with(
+                config={"existing@openstack": {"another_key": "another",
+                                               "https_key": "some key"}},
+                name="from_env"
+            )
 
     @mock.patch("rally.cli.commands.deployment.DeploymentCommands.list")
     @mock.patch("rally.cli.commands.deployment.DeploymentCommands.use")
@@ -280,8 +243,8 @@ class DeploymentCommandsTestCase(test.TestCase):
     @mock.patch("os.remove")
     @mock.patch("os.symlink")
     @mock.patch("os.path.exists", return_value=True)
-    @mock.patch("rally.common.fileutils.update_env_file")
-    def test_use(self, mock_update_env_file, mock_path_exists,
+    @mock.patch("rally.cli.envutils._update_env_file")
+    def test_use(self, mock__update_env_file, mock_path_exists,
                  mock_symlink, mock_remove):
         deployment_id = "593b683c-4b16-4b2b-a56b-e162bd60f10b"
         self.fake_api.deployment.get.return_value = {
@@ -299,7 +262,7 @@ class DeploymentCommandsTestCase(test.TestCase):
                         create=True) as mock_file:
             self.deployment.use(self.fake_api, deployment_id)
             self.assertEqual(3, mock_path_exists.call_count)
-            mock_update_env_file.assert_has_calls([
+            mock__update_env_file.assert_has_calls([
                 mock.call(os.path.expanduser("~/.rally/globals"),
                           "RALLY_DEPLOYMENT", "%s\n" % deployment_id),
                 mock.call(os.path.expanduser("~/.rally/globals"),
@@ -323,8 +286,8 @@ class DeploymentCommandsTestCase(test.TestCase):
     @mock.patch("os.remove")
     @mock.patch("os.symlink")
     @mock.patch("os.path.exists", return_value=True)
-    @mock.patch("rally.common.fileutils.update_env_file")
-    def test_use_with_v3_auth(self, mock_update_env_file, mock_path_exists,
+    @mock.patch("rally.cli.envutils._update_env_file")
+    def test_use_with_v3_auth(self, mock__update_env_file, mock_path_exists,
                               mock_symlink, mock_remove):
         deployment_id = "593b683c-4b16-4b2b-a56b-e162bd60f10b"
 
@@ -345,7 +308,7 @@ class DeploymentCommandsTestCase(test.TestCase):
                         create=True) as mock_file:
             self.deployment.use(self.fake_api, deployment_id)
             self.assertEqual(3, mock_path_exists.call_count)
-            mock_update_env_file.assert_has_calls([
+            mock__update_env_file.assert_has_calls([
                 mock.call(os.path.expanduser("~/.rally/globals"),
                           "RALLY_DEPLOYMENT", "%s\n" % deployment_id),
                 mock.call(os.path.expanduser("~/.rally/globals"),
@@ -371,7 +334,7 @@ class DeploymentCommandsTestCase(test.TestCase):
 
     @mock.patch("rally.cli.commands.deployment.DeploymentCommands."
                 "_update_openrc_deployment_file")
-    @mock.patch("rally.common.fileutils.update_globals_file")
+    @mock.patch("rally.cli.envutils.update_globals_file")
     def test_use_by_name(self, mock_update_globals_file,
                          mock__update_openrc_deployment_file):
         fake_credentials = {"admin": "foo_admin", "users": ["foo_user"]}
@@ -399,7 +362,7 @@ class DeploymentCommandsTestCase(test.TestCase):
 
     @mock.patch("rally.cli.commands.deployment.logging.is_debug",
                 return_value=False)
-    @mock.patch("sys.stdout", new_callable=six.StringIO)
+    @mock.patch("sys.stdout", new_callable=io.StringIO)
     def test_deployment_check(self, mock_stdout, mock_is_debug):
         deployment_uuid = "some"
         # OrderedDict is used to predict the order of platfrom in output
@@ -471,7 +434,7 @@ class DeploymentCommandsTestCase(test.TestCase):
 
     @mock.patch("rally.cli.commands.deployment.logging.is_debug",
                 return_value=True)
-    @mock.patch("sys.stdout", new_callable=six.StringIO)
+    @mock.patch("sys.stdout", new_callable=io.StringIO)
     def test_deployment_check_is_debug_turned_on(self, mock_stdout,
                                                  mock_is_debug):
         deployment_uuid = "some"
